@@ -1,25 +1,14 @@
-/* file: macro.h symmetrica source code */
 #ifndef MACRO_H
 
-#ifdef SYMMAGMA
-#define SYM_MALLOC(a) mem_malloc(a)
-#else
 #define SYM_MALLOC(a) SYM_malloc(a)
-#endif
-
-#ifdef SYMMAGMA
-#define SYM_FREE(a) mem_free(a)
-#else
 #define SYM_FREE(a) SYM_free(a)
-#endif
-
 
 
 #define S_O_S(a) (((OP)(a))->ob_self)
 #define S_O_K(a) (((OP)(a))->ob_kind)
 #define C_O_K(a,b) ((a)->ob_kind = (OBJECTKIND)(b))
 #define C_O_S(a,b) S_O_S(a)=(b)
-#define B_KS_O(a,b,c) do { C_O_S(c,b); C_O_K(c,a); } while(0) 
+#define B_KS_O(a,b,c) do { C_O_S(c,b); C_O_K(c,a); } while(0)
 
 #define EMPTYP(a) ((a)->ob_kind == (OBJECTKIND)0)
 
@@ -129,7 +118,6 @@ C_V_S(b,a);C_V_L(b,CALLOCOBJECT()); M_I_I(1,S_V_L(b)); } while(0)
             || (S_O_K(a) == MONOMIAL) \
             || (S_O_K(a) == HOM_SYM) \
         )
- 
 
 
 #define S_L_S(a) ((((a)->ob_self).ob_list)->l_self)
@@ -137,7 +125,7 @@ C_V_S(b,a);C_V_L(b,CALLOCOBJECT()); M_I_I(1,S_V_L(b)); } while(0)
 #define S_L_N(a) ((((a)->ob_self).ob_list)->l_next)
 #define C_L_N(a,b) (((((a)->ob_self).ob_list)->l_next) = (OP)(b))
 
-#define S_PA_C(a) ((unsigned char *)  (S_PA_S(a))) 
+#define S_PA_C(a) ((unsigned char *)  (S_PA_S(a)))
 #define S_PA_K(a) ((a)->ob_self.ob_partition->pa_kind)
 #define C_PA_K(a,b) (((((a)->ob_self).ob_partition)->pa_kind) = b)
 #define C_PA_HASH(a,b) (((((a)->ob_self).ob_partition)->pa_hash) = b)
@@ -181,7 +169,7 @@ FREE_MEMMANAGER(struct partition *,\
                     partition_speichersize,\
                     mem_counter_part,\
                     d)
- 
+
 #define B_KS_PA(a,b,c) \
     do {\
     C_O_K(c,PARTITION);\
@@ -190,24 +178,22 @@ FREE_MEMMANAGER(struct partition *,\
                       partition_speicherindex,\
                       mem_counter_part,\
                       (c ->ob_self).ob_partition);\
-    /* (c ->ob_self).ob_partition=CALLOCPARTITION();*/\
     C_PA_K(c,a);\
     C_PA_S(c,b);\
     C_PA_HASH(c,-1L); \
     } while (0)
- 
+
 #define M_KL_PA(a,b,c) \
 do { B_KS_PA(a,CALLOCOBJECT(),c);\
         erg += m_l_v(b,S_PA_S(c));\
         C_O_K(S_PA_S(c),INTEGERVECTOR) );\
 while(0)
- 
+
 #define B_KL_PA(a,b,c) \
 do { B_KS_PA(a,CALLOCOBJECT(),c);\
         erg += b_l_v(b,S_PA_S(c));\
         C_O_K(S_PA_S(c),INTEGERVECTOR);\
 } while(0)
- 
 
 
 
@@ -220,7 +206,7 @@ do { B_KS_PA(a,CALLOCOBJECT(),c);\
 #define S_P_L(a) S_V_L(S_P_S(a))
 #define S_P_LI(a) S_V_LI(S_P_S(a))
 
-/* kranz produkt AK 120804 */
+/* kranz produkt */
 #define S_KR_G(a) S_V_I(a,0)
 #define S_KR_GI(a,i) S_P_I(S_V_I(a,0),i)
 #define S_KR_GL(a) S_P_L(S_V_I(a,0))
@@ -243,7 +229,7 @@ do { B_KS_PA(a,CALLOCOBJECT(),c);\
 #define S_M_IJ(a,i,j) ( ((((a)->ob_self).ob_matrix)->m_self)\
      + ((((((a)->ob_self).ob_matrix)->m_length)->ob_self).ob_INT)\
      * (i) + (j) )
-#define S_M_IJI(a,i,j) S_I_I(S_M_IJ(a,i,j)) 
+#define S_M_IJI(a,i,j) S_I_I(S_M_IJ(a,i,j))
 #define MATRIXP(a) ((S_O_K(a) == MATRIX) || (S_O_K(a) == KRANZTYPUS)\
     || (S_O_K(a) == KOSTKA) || (S_O_K(a) == INTEGERMATRIX) )
 
@@ -448,8 +434,6 @@ do {\
 #define    NEGEINSP_SQRAD(a)    eq_fieldobject_int(SQ_RADICAL,(a),-1L)
 
 
-
-
 #define evenp(a) even(a)
 #define oddp(a) odd(a)
 #define first_ym(a,b) ym_min(a,b)
@@ -527,9 +511,7 @@ do {\
 #define S_GL_GLNQ_Q(a) (S_V_I(S_V_I(a,1L),1L))
 
 
-
 /* for ga.c */
-
 #define m_skn_gral(a,b,c,d) ( m_skn_po(a,b,c,d), C_O_K(d,GRAL), OK )
 #define b_skn_gral(a,b,c,d) ( b_skn_po(a,b,c,d), C_O_K(d,GRAL), OK )
 #define hplus_hecke(a,b) hplus(a,b)
@@ -551,9 +533,7 @@ do {\
 #define S_GR_DI(a) S_V_II(a,0)
 
 
-
 /* for longint */
-
 extern INT loc_index, loc_size,loc_counter;
 extern struct loc **loc_speicher;
 
@@ -566,7 +546,7 @@ extern struct longint **longint_speicher;
     FREE_MEMMANAGER(struct loc *,loc_speicher,loc_index,loc_size,loc_counter,a)
 
 #define LOCSGN(lx) ( ((lx)->w2 || (lx)->w1 || (lx)->w0 ) ? 1 : 0 )
- 
+
 #define LOCNULL(lx) ((lx)->w0=0,(lx)->w1=0,(lx)->w2=0)
 
 #define LOCHOLE(aloc) \
@@ -590,7 +570,7 @@ do {\
       (x->floc->w0&BMINUSEINS)\
               +(x->floc->w1&BMINUSEINS) * LO_B\
               +(x->floc->w2&BMINUSEINS) * LO_B * LO_B )
- 
+
 #define T_LONGINT_INT(a)\
     if ((S_O_S(a).ob_longint) ->laenge == 1)\
         if (S_O_S(a).ob_longint ->floc ->w2 <= 1) /* AK 051101 */\
@@ -614,7 +594,7 @@ do {\
 #define t_INTEGER_LONGINT(a,b) m_i_longint(a,b)
 
 #ifdef FAST
-#define SYMCHECK(a,b) 
+#define SYMCHECK(a,b)
 #define COP(text,object)
 #define CTO(type,text,object)
 #define CTTO(type,type2,text,object)
@@ -722,7 +702,7 @@ do {\
 #define TCTTO(type,type2,text,object) \
        CTTO(type,type2,text,object);\
        printf("%s=",text);println(object);
-       
+
 #define TCTTTO(type,type2,type3,text,object) \
         COP(text,object);\
         if((S_O_K(object) != type)&&\
@@ -731,7 +711,7 @@ do {\
             goto endr_ende;\
        }\
        printf("%s=",text);println(object);
-      
+
 #define TCTTTTO(type,type2,type3,type4,text,object) \
         COP(text,object);\
         if((S_O_K(object) != type)&&(S_O_K(object) != type4)&&\
@@ -783,7 +763,7 @@ do {\
        }\
        printf("%s=",text);println(object);
 
- 
+
 #endif
 #define C2R(a,b,t,c) if (check_result_2(a,b,t,c) \
     != NORESULT) goto strlabel
@@ -846,8 +826,7 @@ do {\
         }\
     else\
         {\
-        if (c != NULL)\
-            FREESELF(c);\
+        if (c != NULL) { FREESELF(c); }\
         }
 
 #define CE4(a,b,c,d,f) \
@@ -858,22 +837,13 @@ do {\
     f,&erg) == EQUAL) goto endr_ende;
 
 #define GET_BIT_I(a,i) (((*a) >> (i))&1)
-/*
-#define GET_BV_I(a,i) ((*(((unsigned char *)S_V_S(a) ) + ((i)>>3))  >> ((i)&7))&1)
-*/
 #define GET_BV_I(a,i) ((*(((unsigned char *)S_V_S(a) ) + ((i)>>3))  >> (7-((i)&7))&1))
-#define GET_BV_B(a,i) (*(((unsigned char *)S_V_S(a) ) + (i)>>3)) 
-/* 
-#define UNSET_BV_I(a,i) (*((unsigned char *)S_V_S(a)  + ((i)>>3))  &= (~(1 << ((i)&7)))) 
-*/
+#define GET_BV_B(a,i) (*(((unsigned char *)S_V_S(a) ) + (i)>>3))
 #define UNSET_BV_I(a,i) (\
     *((unsigned char *)S_V_S(a)  + ((i)>>3))  \
     &= (~(1 << (7-((i)&7))       )           )\
-    ) 
+    )
 #define UNSET_BIT_I(a,i) ((*(a))  &= (~(1 << (i))))
-/*
-#define SET_BV_I(a,i) ( *((unsigned char *)S_V_S(a)  + ((i)>>3))  |= (1 << ((i)&7)))
-*/
 #define SET_BV_I(a,i) ( *((unsigned char *)S_V_S(a)  + ((i)>>3))  |= (128 >> ((i)&7)))
 #define SET_BIT_I(a,i) ( *(a)  |= (1 << (i)))
 #define S_BV_LI(a) (S_V_LI(a) % 8 == 0 ? S_V_LI(a)>>3 : (S_V_LI(a)>>3) +1)
@@ -918,27 +888,7 @@ return 0;\
 
 
 
-
-
-
-
-
-
 /* FOR ALL macros */
-#define FORALL_HASHTABLE_PRE060202(z,a,B)\
-do { \
-    OP FORALL_E;INT I,J; \
-    for (FORALL_E=S_V_S(a), I=0; I<S_V_LI(a); I++,FORALL_E++) \
-        {\
-        if (S_O_K(FORALL_E)==VECTOR)\
-           for (J=0;J<S_V_LI(FORALL_E) ;J++) \
-               { \
-               z = S_V_I(FORALL_E,J); \
-               if (not EMPTYP(z)) {B;} \
-               } \
-        }\
-} while(0)
-
 #define FORALL_HASHTABLE(z,a,B)\
 do { \
     OP FORALL_E;INT I,J; \
@@ -984,11 +934,7 @@ else if (VECTORP(a)) {\
 }
 
 
-
-
-
 /* new macros for main functions */
-
 #define ABSOLUTE_INTEGER(a,b) \
     M_I_I((S_I_I(a) > 0 ? S_I_I(a) : -S_I_I(a)), b)
 
@@ -1047,12 +993,13 @@ else erg += addinvers(a,b)
 #define ADDINVERS_APPLY_LONGINT(a) erg += (GANZNEG(S_O_S(a).ob_longint),OK)
 #define ADDINVERS_APPLY_INTEGER(a) M_I_I( - S_I_I(a),a)
 
-#define ADDINVERS_APPLY(a)\
+#define ADDINVERS_APPLY(a) do {\
 if (S_O_K(a) == INTEGER) ADDINVERS_APPLY_INTEGER(a);\
 else if (S_O_K(a) == LONGINT) ADDINVERS_APPLY_LONGINT(a);\
 else if (S_O_K(a) == BRUCH) erg += addinvers_apply_bruch(a);\
 else if (S_O_K(a) == MONOM) erg += addinvers_apply_monom(a);\
-else erg += addinvers_apply(a)
+else erg += addinvers_apply(a);\
+} while(0)
 
 
 #define BINOM_POSINTEGER_POSINTEGER(a,b,c)\
@@ -1063,24 +1010,13 @@ if (S_I_I(a) < BINOMLIMIT) {\
     }\
 else binom(a,b,c)
 
-
-/*
-#ifdef SYMMAGMA
-#define CALLOCOBJECT() \
-       ( (freeall_speicherposition >= 0L) ? \
-         freeall_speicher[freeall_speicherposition--] : \
-         mem_calloc(sizeof(struct object),1) )
-#define CALLOCOBJECT() (OP)mem_calloc(sizeof(struct object),1)
-#else
-*/
 /* freeall_speicherposition is next free object */
-#define CALLOCOBJECT() \
-       ( (freeall_speicherposition >= 0L) ? \
-         freeall_speicher[freeall_speicherposition--] : \
-         callocobject_fast() )
-/*
-#endif
-*/
+static inline OP CALLOCOBJECT(void)
+{
+    if (freeall_speicherposition >= 0L)
+        return freeall_speicher[freeall_speicherposition--];
+    return callocobject_fast();
+}
 
 #define CALLOCOBJECT2(a,b) \
 do { a=CALLOCOBJECT(); b=CALLOCOBJECT(); } while(0)
@@ -1132,7 +1068,7 @@ do { a=CALLOCOBJECT(); b=CALLOCOBJECT(); h=CALLOCOBJECT(); i=CALLOCOBJECT();\
           )\
        )\
     )
-    
+
 #define COPY(a,b) \
     ( (S_O_K(a) == INTEGER) ? M_I_I(S_I_I(a),b):\
       ( (S_O_K(a) == LONGINT) ? copy_longint(a,b): \
@@ -1247,7 +1183,6 @@ do { switch(S_O_K(b)) {\
 } while(0)
 
 
-
 #define CLEVER_COPY(a,b) \
 do { if (S_O_K(a) == INTEGER) CLEVER_COPY_INTEGER(a,b);\
 else if (S_O_K(a) == LONGINT) CLEVER_COPY_LONGINT(a,b);\
@@ -1258,7 +1193,6 @@ else { erg += copy(a,b); }\
 } while(0)
 
 
-
 #define DEC(a)\
 if (S_O_K(a) == INTEGER) DEC_INTEGER(a);\
 else if (S_O_K(a) == LONGINT) erg+= dec_longint(a);\
@@ -1324,7 +1258,6 @@ else dec(a)
 #define FREEALL_INTEGER(a) do { C_O_K(a,EMPTY); FREE_EMPTY_OBJECT(a); } while(0)
 #define FREESELF_INTEGERVECTOR(a) \
     do {\
-        extern INT freevectorstruct();\
         if (S_V_LI(a) == (INT)1) FREEALL_INTEGER(S_V_S(a));\
         else if (S_V_LI(a) > (INT)0) SYM_free(S_V_S(a));\
         FREEALL_INTEGER(S_V_L(a));\
@@ -1333,9 +1266,8 @@ else dec(a)
     } while(0)
 #define FREEALL_INTEGERVECTOR(a) do { \
     FREESELF_INTEGERVECTOR(a); FREE_EMPTY_OBJECT(a); } while(0)
-       
-    
-#define FREESELF(a) \
+
+#define FREESELF(a) do {\
     if (S_O_K(a) == EMPTY);\
     else if (S_O_K(a) == INTEGER) C_O_K(a,EMPTY);\
     else if (S_O_K(a) == LONGINT)  erg += freeself_longint(a);  \
@@ -1351,36 +1283,37 @@ else dec(a)
     else if (S_O_K(a) == PERMUTATION)  erg += freeself_permutation(a);  \
     else if (S_O_K(a) == SKEWPARTITION)  erg += freeself_skewpartition(a);  \
     else if (S_O_K(a) == FF)  erg += freeself_ff(a);  \
-    else erg += freeself(a)
+    else erg += freeself(a);\
+} while(0)
 
 #define FREESELF2(a,b) do { FREESELF(a); FREESELF(b); } while(0)
-#define FREESELF2(a,b) do { FREESELF(a); FREESELF(b); } while(0) 
-#define FREESELF3(a,b,c) do { FREESELF(a); FREESELF(b); FREESELF(c); } while(0) 
-#define FREESELF4(a,b,c,d) do { FREESELF2(a,b); FREESELF2(c,d); } while(0) 
-#define FREESELF5(a,b,c,d,e) do { FREESELF2(a,b); FREESELF3(c,d,e); } while(0) 
-#define FREESELF6(a,b,c,d,e,f) do { FREESELF3(a,b,f); FREESELF3(c,d,e); } while(0) 
-#define FREESELF7(a,b,c,d,e,f,g) do { FREESELF4(a,b,f,g); FREESELF3(c,d,e); } while(0) 
+#define FREESELF2(a,b) do { FREESELF(a); FREESELF(b); } while(0)
+#define FREESELF3(a,b,c) do { FREESELF(a); FREESELF(b); FREESELF(c); } while(0)
+#define FREESELF4(a,b,c,d) do { FREESELF2(a,b); FREESELF2(c,d); } while(0)
+#define FREESELF5(a,b,c,d,e) do { FREESELF2(a,b); FREESELF3(c,d,e); } while(0)
+#define FREESELF6(a,b,c,d,e,f) do { FREESELF3(a,b,f); FREESELF3(c,d,e); } while(0)
+#define FREESELF7(a,b,c,d,e,f,g) do { FREESELF4(a,b,f,g); FREESELF3(c,d,e); } while(0)
 
 #define FREEALL(a) do { FREESELF(a); FREE_EMPTY_OBJECT(a); } while(0)
-#define FREEALL2(a,b) do { FREEALL(a); FREEALL(b); } while(0) 
-#define FREEALL3(a,b,c) do { FREEALL(a); FREEALL(b); FREEALL(c); } while(0) 
-#define FREEALL4(a,b,c,d) do { FREEALL(a); FREEALL(b); FREEALL(c);FREEALL(d); } while(0) 
-#define FREEALL5(a,b,c,d,e) do { FREEALL2(a,b); FREEALL3(c,d,e); } while(0) 
-#define FREEALL6(a,b,c,d,e,f) do { FREEALL3(a,b,f); FREEALL3(c,d,e); } while(0) 
-#define FREEALL7(a,b,c,d,e,f,g) do { FREEALL4(a,b,f,g); FREEALL3(c,d,e); } while(0) 
-#define FREEALL8(a,b,c,d,e,f,g,h) do { FREEALL4(a,b,f,g); FREEALL4(c,d,e,h); } while(0) 
-#define FREEALL9(a,b,c,d,e,f,g,h,i) do { FREEALL4(a,b,f,g); FREEALL5(c,d,e,h,i); } while(0) 
+#define FREEALL2(a,b) do { FREEALL(a); FREEALL(b); } while(0)
+#define FREEALL3(a,b,c) do { FREEALL(a); FREEALL(b); FREEALL(c); } while(0)
+#define FREEALL4(a,b,c,d) do { FREEALL(a); FREEALL(b); FREEALL(c);FREEALL(d); } while(0)
+#define FREEALL5(a,b,c,d,e) do { FREEALL2(a,b); FREEALL3(c,d,e); } while(0)
+#define FREEALL6(a,b,c,d,e,f) do { FREEALL3(a,b,f); FREEALL3(c,d,e); } while(0)
+#define FREEALL7(a,b,c,d,e,f,g) do { FREEALL4(a,b,f,g); FREEALL3(c,d,e); } while(0)
+#define FREEALL8(a,b,c,d,e,f,g,h) do { FREEALL4(a,b,f,g); FREEALL4(c,d,e,h); } while(0)
+#define FREEALL9(a,b,c,d,e,f,g,h,i) do { FREEALL4(a,b,f,g); FREEALL5(c,d,e,h,i); } while(0)
 
 #define GANZDIV_INTEGER(a,b,c) \
     if (S_O_K(b) == INTEGER) M_I_I(S_I_I(a)/S_I_I(b),c);\
     else if (S_O_K(b) == LONGINT) erg += ganzdiv_integer_longint(a,b,c);\
     else  erg += ganzdiv_integer(a,b,c)
- 
+
 #define GANZDIV_LONGINT(a,b,c) \
     if (S_O_K(b) == INTEGER) erg += ganzdiv_longint_integer(a,b,c);\
     else if (S_O_K(b) == LONGINT) erg += ganzdiv_longint_longint(a,b,c);\
     else  erg += ganzdiv_longint(a,b,c)
- 
+
 #define GANZDIV(a,b,c) \
 if (S_O_K(a) == INTEGER)    GANZDIV_INTEGER(a,b,c); \
 else if (S_O_K(a) == LONGINT)  GANZDIV_LONGINT(a,b,c); \
@@ -1454,10 +1387,11 @@ else\
       ( S_O_K(a) == INTEGER ? S_I_I(a) : hash(a) )\
     )
 
-#define INC(a)\
+#define INC(a) do {\
 if (S_O_K(a) == INTEGER) INC_INTEGER(a);\
 else if (S_O_K(a) == LONGINT) erg+= inc_longint(a);\
-else inc(a)
+else inc(a);\
+} while(0)
 
 #define INSERT_BINTREE(a,b,eh,cf) insert_bintree(a,b,eh,cf)
 #define INSERT_HASHTABLE(a,b,eh,cf,hf) \
@@ -1471,11 +1405,11 @@ else inc(a)
 #define INSERT_LIST(a,b,eh,cf) \
     if (LISTP(a)) insert_list_list(a,b,eh,cf); \
     else insert_list(a,b,eh,cf)
-    
+
 #define INSERT(a,b,eh,cf) \
     if (S_O_K(b) == HASHTABLE) INSERT_HASHTABLE(a,b,eh,cf,hash); \
     else if (S_O_K(b) == BINTREE) INSERT_BINTREE(a,b,eh,cf); \
-    else INSERT_LIST(a,b,eh,cf) 
+    else INSERT_LIST(a,b,eh,cf)
 
 #define INSERT_SCHURMONOM_(m,c)\
     if (S_O_K(c) == HASHTABLE)\
@@ -1518,9 +1452,6 @@ else inc(a)
        WTO("INSERT_HOMSYMMONOM_(2)",c)
 
 
-
-
- 
 #define INTLOGPOS5_4(ai)   (( ai >= 10000L)     ? 5 : 4)
 #define INTLOGPOS5_3(ai)   (( ai >= 1000L)      ? INTLOGPOS5_4(ai) : 3)
 #define INTLOGPOS2_1(ai)   (( ai >= 10L)        ? 2 : 1)
@@ -1595,14 +1526,15 @@ else erg += mod_apply(a,b)
             }\
     else M_I_I(S_I_I(a)*S_I_I(b),b)
 
-#define MULT_APPLY_INTEGER(a,b) \
+#define MULT_APPLY_INTEGER(a,b) do {\
     if (S_O_K(b) == INTEGER) MULT_APPLY_INTEGER_INTEGER(a,b);\
     else if (S_O_K(b) == LONGINT) erg += mult_apply_integer_longint(a,b);\
     else if (S_O_K(b) == BRUCH) erg += mult_apply_integer_bruch(a,b);\
     else if (S_O_K(b) == MONOM) erg += mult_apply_integer_monom(a,b);\
     else if (POLYP(b)) erg += mult_apply_integer_polynom(a,b);\
     else if (S_O_K(b) == HASHTABLE) erg += mult_apply_integer_hashtable(a,b);\
-    else  erg += mult_apply_integer(a,b)
+    else  erg += mult_apply_integer(a,b);\
+} while(0)
 
 #define MULT_APPLY_LONGINT(a,b)\
     if (S_O_K(b) == INTEGER) erg += mult_apply_longint_integer(a,b);\
@@ -1619,14 +1551,14 @@ else erg += mod_apply(a,b)
     else if (S_O_K(b) == HASHTABLE) erg += mult_apply_bruch_hashtable(a,b);\
     else  erg += mult_apply_bruch(a,b)
 
-#define MULT_APPLY(a,b) \
+#define MULT_APPLY(a,b) do {\
 if (S_O_K(a) == INTEGER)  MULT_APPLY_INTEGER(a,b);\
 else if (S_O_K(a) == LONGINT)  MULT_APPLY_LONGINT(a,b);\
 else if (S_O_K(a) == BRUCH)   MULT_APPLY_BRUCH(a,b);\
 else if (S_O_K(a) == POLYNOM)   erg += mult_apply_polynom(a,b);\
 else if (S_O_K(a) == FF)   erg += mult_apply_ff(a,b);\
-else\
-    erg += mult_apply(a,b)
+else erg += mult_apply(a,b);\
+} while(0)
 
 #define MULT_INTEGER_INTEGER(a,b,c) \
     if (INTLOG(a) + INTLOG(b) > 9) {\
@@ -1702,7 +1634,7 @@ if (S_O_K(b) == FF) {\
         default: FREESELF(c); mult_ff_ff(a,b,c); break;\
         }\
     }\
-else do { FREESELF(c); erg += mult_ff(a,b,c); } while(0) 
+else do { FREESELF(c); erg += mult_ff(a,b,c); } while(0)
 
 #define CLEVER_MULT(a,b,c) \
 if (S_O_K(a) == INTEGER)    CLEVER_MULT_INTEGER(a,b,c); \
@@ -1825,6 +1757,9 @@ do { \
         *b = swap_object; \
         } while(0)
 
+/* Helper for use in functions of two OP arguments. When the arguments
+ * are equal, this makes a copy of the second argument and then operates
+ * on the copy instead of the original (i.e. the first argument). */
 #define CE2(a,b,f) \
     if (a==b)  {\
         OP checkequal2_c = CALLOCOBJECT();\
@@ -1834,7 +1769,8 @@ do { \
         FREEALL(checkequal2_c);\
         goto endr_ende;\
         }\
-    else   FREESELF(b) 
+    else   FREESELF(b)
+
 /* used for transfunctions */
 #define TCE2(a,b,f,typ) \
     if (a==b)  {\
@@ -1852,8 +1788,6 @@ do { \
     ADD_APPLY(S_MO_K(a), S_MO_K(b));\
     if (NULLP(S_MO_K(b)))\
         FREESELF_MONOM(b)
- 
-    
 
 #define M_FORALL_MONOMIALS_IN_AB(a,b,c,f,partf)\
 {\
@@ -1910,7 +1844,6 @@ ff = CALLOCOBJECT();\
 }
 
 
-
 #define M_FORALL_MONOMIALS_IN_B(a,b,c,f,partf)\
 {\
 OP ff,z;\
@@ -2026,7 +1959,6 @@ else {\
 }
 
 
-
 #define T_FORALL_MONOMIALS_IN_A(a,b,f,partf)\
 {\
 OP ff,z;\
@@ -2071,8 +2003,7 @@ INSERT_LIST(m,c,add_koeff,comp_monommonomial);\
 #define LT(a,b) (COMP(a,b) < (INT)0)
 
 
-/* speicher managment */
-
+/* speicher management */
 #define FREE_MEMMANAGER(t,s,i,g,c,v)\
 do {\
     c--;\
@@ -2095,19 +2026,18 @@ do {\
        }\
     else s[++i] = (v);\
 } while(0)
- 
+
 #define CALLOC_MEMMANAGER(t,s,i,c,v)\
 do {\
     c++;\
     if (i>=0) v = s[i--];\
     else v = (t*) SYM_MALLOC(sizeof(t));\
 } while(0)
- 
+
 #define ANFANG_MEMMANAGER(s,i,g,c) \
 s = NULL; i = -1; c = 0; g = 0
- 
+
 #define ENDE_MEMMANAGER(s,i,g,c,text) \
-if (no_banner != TRUE) { SYMCHECK(c, text);} \
 if (s != NULL) { \
     INT jj;\
     for (jj = 0; jj<=i;jj++) SYM_FREE(s[jj]);\
